@@ -88,7 +88,7 @@ def write_report(name, project, logger, result, console_out):
         logger.error("Test failed: %s", failure[0].id())
         
         if project.verbose:
-            print "\n" + failure[1].replace("Traceback (most recent call last):\n", "") \
-                                   .replace("AssertionError", "\nAssertionError")
+            sys.stdout.write("\n" + failure[1].replace("Traceback (most recent call last):\n", "")
+                                              .replace("AssertionError", "\nAssertionError"))
     
     project.write_report("%s.json" % name, render_report(report))
